#ifndef KICONBAR_H
#define KICONBAR_H

#include "gui_g.h"
#include <QFrame>
#include <QIcon>
#include <QLabel>
#include <QString>

namespace kdk
{

/** @defgroup bar模块
  * @{
  */

class KIconBarPrivate;

/**
 * @brief 图标和标题组合控件
 */
class GUI_EXPORT KIconBar:public QFrame
{
    Q_OBJECT
public:
    KIconBar(QWidget* parent = nullptr);
    KIconBar(const QString& iconName,const QString& text,QWidget* parent = nullptr);
    ~KIconBar();

    /**
     * @brief 设置图标
     * @param iconName
     */
    void setIcon(const QString& iconName);

    /**
     * @brief 设置图标
     * @param icon
     */
    void setIcon(const QIcon& icon);

    /**
     * @brief 设置标题
     * @param widgetName
     */
    void setWidgetName(const QString& widgetName);

    /**
     * @brief 获取标题label
     * @return
     */
    QLabel* nameLabel();

    /**
     * @brief 获取图标label
     * @return
     */
    QLabel* iconLabel();

Q_SIGNALS:
    /**
     * @brief 双击会发出双击信号，父widget可以绑定相应槽函数
     */
    void doubleClick();

protected:
    void mouseDoubleClickEvent(QMouseEvent *event);
    void resizeEvent(QResizeEvent *event);
    QSize sizeHint() const override;

private:
    Q_DECLARE_PRIVATE(KIconBar)
    KIconBarPrivate*const d_ptr;

};
}
/**
  * @example testWidget/testwidget.h
  * @example testWidget/testwidget.cpp
  * @}
  */
#endif // KICONBAR_H
