#ifndef KPRESSBUTTON_H
#define KPRESSBUTTON_H
#include "gui_g.h"
#include <QPushButton>
#include <QWidget>
namespace kdk {

class KPressButtonPrivate;

/**
 * @brief The KPressButton class  since 1.2.0.10
 */
class GUI_EXPORT KPressButton:public QPushButton
{
    Q_OBJECT
public:
    enum ButtonType{
        NormalType,
        CircleType
    };

    KPressButton(QWidget* parent = 0);

    /**
     * @brief 设置圆角
     * @param radius
     */
    void setBorderRadius(int radius);

    /**
     * @brief 设置圆角
     * @param buttomLeft
     * @param topLeft
     * @param topRight
     * @param bottomRight
     */
    void setBorderRadius(int bottomLeft,int topLeft,int topRight,int bottomRight);

    /**
     * @brief 设置是否可选中
     * @param flag
     */
    void setCheckable(bool);

    /**
     * @brief 返回是否可选中
     * @return
     */
    bool isCheckable() const;

    /**
     * @brief 设置是否选中
     * @return
     */
    void setChecked(bool);

    /**
     * @brief 返回是否选中
     * @return
     */
    bool isChecked() const;

    /**
     * @brief 设置button类型
     * @param type
     */
    void setButtonType(ButtonType type);

    /**
     * @brief 返回button类型
     * @return
     */
    KPressButton::ButtonType buttonType();

    /**
     * @brief 设置是否启用loading状态
     * @param flag
     */
    void setLoaingStatus(bool flag);

    /**
     * @brief 返回是否启用loading状态
     * @return
     */
    bool isLoading();

    /**
     * @brief 设置是否启用透明度
     * @param flag
     */
    void setTranslucent(bool flag);

    /**
     * @brief 返回是否启用透明度
     * @return
     */
    bool isTranslucent();
protected:
   void paintEvent(QPaintEvent *event) override;

private:
    Q_DECLARE_PRIVATE(KPressButton)
    KPressButtonPrivate* const d_ptr;
};

}
#endif // KPRESSBUTTON_H
