#ifndef KSWITCHBUTTON_H
#define KSWITCHBUTTON_H

#include "gui_g.h"
#include <QPushButton>
#include <QTimer>
#include <QPainter>
#include <QGSettings/QGSettings>

namespace kdk
{

/** @defgroup 按钮模块
  * @{
  */

class KSwitchButtonPrivate;

/**
 * @brief KSwitchButton，指示打开/关闭两种状态
 */
class GUI_EXPORT KSwitchButton:public QPushButton
{
    Q_OBJECT

public:
    KSwitchButton(QWidget* parent = 0);
    ~KSwitchButton();

    /**
     * @brief 设置是否可选中
     */
    void setCheckable(bool);

    /**
     * @brief 返回是否可选中
     * @return
     */
    bool isCheckable() const;

    /**
     * @brief 返回是否选中
     * @return
     */
    bool isChecked() const;

    /**
     * @brief 设置是否选中
     * @return
     */
    void setChecked(bool);

    /**
     * @brief 设置是否启用半透明效果，since 1.2.0.10
     * @param flag
     */
    void setTranslucent(bool flag);

    /**
     * @brief 获取是否启用半透明效果，since 1.2.0.10
     * @return flag
     */
    bool isTranslucent();

Q_SIGNALS:
    /**
     * @brief 当选中状态发生变化时，发出此信号
     */
    void stateChanged(bool);

protected:
   void paintEvent(QPaintEvent *event) override;
   void resizeEvent(QResizeEvent *event) override;
   QSize sizeHint() const;
    
private:
    Q_DECLARE_PRIVATE(KSwitchButton)
    KSwitchButtonPrivate* const d_ptr;
};

}
/**
  * @example testSwitchbutton/widget.h
  * @example testSwitchbutton/widget.cpp
  * @}
  */
#endif //KSWITCHBUTTON_H
