#ifndef KTITLEBAR_H
#define KTITLEBAR_H

#include "gui_g.h"
#include "kmenubutton.h"
#include <QFrame>
#include <QPushButton>
#include <QMouseEvent>
#include <QDebug>

namespace kdk
{

/** @defgroup 对话框模块
  * @{
  */

enum MaximumButtonState
{
    Maximum,
    Restore
};
class KWindowButtonBarPrivate;

/**
 * @brief 窗口三联按钮和菜单按钮的集合
 */
class GUI_EXPORT KWindowButtonBar:public QFrame
{
    Q_OBJECT

public:
    KWindowButtonBar(QWidget*parent=nullptr);
    ~KWindowButtonBar();

    /**
     * @brief 获取最小化按钮
     * @return
     */
    QPushButton* minimumButton();

    /**
     * @brief 获取最大化按钮
     * @return
     */
    QPushButton* maximumButton();

    /**
     * @brief 获取关闭按钮
     * @return
     */
    QPushButton* closeButton();

    /**
     * @brief 获取菜单按钮
     * @return
     */
    KMenuButton* menuButton();

    /**
     * @brief 获取最大化按钮的状态(最大化/恢复)
     * @return
     */
    MaximumButtonState maximumButtonState();

    /**
     * @brief 设置最大化按钮图标状态（最大化/恢复）
     * @param state
     */
    void setMaximumButtonState(MaximumButtonState state);



Q_SIGNALS:
    /**
     * @brief 双击会发出双击信号，父widget可以绑定相应槽函数
     */
    void doubleClick();

protected:
    void mouseDoubleClickEvent(QMouseEvent *event);
    bool eventFilter(QObject *watched, QEvent *event);
    QSize sizeHint() const override;

private:
    Q_DECLARE_PRIVATE(KWindowButtonBar)
    KWindowButtonBarPrivate *d_ptr;
};
}
/**
  * @example testWidget/testwidget.h
  * @example testWidget/testwidget.cpp
  * @}
  */

#endif //KTITLEBAR_H
